@@ -5,7 +5,7 @@ var files_dup =
     [ "ConsoleProgress.hpp", "ConsoleProgress_8hpp_source.html", null ],
     [ "Crc32Tab.hpp", "Crc32Tab_8hpp_source.html", null ],
     [ "Data.hpp", "Data_8hpp_source.html", null ],
-    [ "file.hpp", "file_8hpp.html", "file_8hpp" ],
+    [ "file.hpp", "file_8hpp_source.html", null ],
     [ "Keys.hpp", "Keys_8hpp_source.html", null ],
     [ "KeystreamTab.hpp", "KeystreamTab_8hpp_source.html", null ],
     [ "log.hpp", "log_8hpp.html", "log_8hpp" ],
